Returns the character vector of topic names accepted by
ptr_llm_topic(). Matches the files in inst/llm/topics/ (stripped
of the .md extension), sorted alphabetically.
Returns the character vector of topic names accepted by
ptr_llm_topic(). Matches the files in inst/llm/topics/ (stripped
of the .md extension), sorted alphabetically.